==> jc-1.4.0.tar.gz: soot/jimple/internal/JNewArrayExpr.h <==
// public class soot.jimple.internal.JNewArrayExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class cc0d5acb5fd5a93a soot_jimple_internal_AbstractNewArrayExpr
// @dep_class 679d3e54c99aea5a soot_jimple_internal_JNewArrayExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractNewArrayExpr

#include "soot/jimple/internal/AbstractNewArrayExpr.h"

#ifndef _JC_soot_jimple_internal_JNewArrayExpr_H_
#define _JC_soot_jimple_internal_JNewArrayExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Type$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JNewArrayExpr$sub_refs	_jc_soot_jimple_internal_JNewArrayExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_JNewArrayExpr$sub_nonrefs	_jc_soot_jimple_internal_JNewArrayExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JNewArrayExpr$refs	_jc_soot_jimple_internal_JNewArrayExpr$refs;
typedef struct _jc_soot_jimple_internal_JNewArrayExpr$nonrefs	_jc_soot_jimple_internal_JNewArrayExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_JNewArrayExpr$object	_jc_soot_jimple_internal_JNewArrayExpr$object;

typedef const struct _jc_soot_jimple_internal_JNewArrayExpr$vmethods	_jc_soot_jimple_internal_JNewArrayExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_JNewArrayExpr$vtable	_jc_soot_jimple_internal_JNewArrayExpr$vtable;
typedef const struct _jc_soot_jimple_internal_JNewArrayExpr$vtype	_jc_soot_jimple_internal_JNewArrayExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JNewArrayExpr$method$_init$0b3348c37b519d7f(_jc_env *, struct _jc_soot_jimple_internal_JNewArrayExpr$object *, struct _jc_soot_Type$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JNewArrayExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JNewArrayExpr$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JNewArrayExpr$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_jimple_internal_JNewArrayExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JNewArrayExpr$object *);
};

// Vtable
struct _jc_soot_jimple_internal_JNewArrayExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractNewArrayExpr$vmethods	soot_jimple_internal_AbstractNewArrayExpr;
	_jc_soot_jimple_internal_JNewArrayExpr$vmethods	soot_jimple_internal_JNewArrayExpr;
};

// Vtype
struct _jc_soot_jimple_internal_JNewArrayExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JNewArrayExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JNewArrayExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JNewArrayExpr$refs {
    _jc_soot_jimple_internal_JNewArrayExpr$sub_refs	soot_jimple_internal_JNewArrayExpr;
    _jc_soot_jimple_internal_AbstractNewArrayExpr$sub_refs	soot_jimple_internal_AbstractNewArrayExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JNewArrayExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JNewArrayExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractNewArrayExpr$sub_nonrefs	soot_jimple_internal_AbstractNewArrayExpr;
    _jc_soot_jimple_internal_JNewArrayExpr$sub_nonrefs	soot_jimple_internal_JNewArrayExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_JNewArrayExpr$object {
	_jc_soot_jimple_internal_JNewArrayExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JNewArrayExpr$vtype	*vtype;
	_jc_soot_jimple_internal_JNewArrayExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JNewArrayExpr$vtype _jc_soot_jimple_internal_JNewArrayExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JNewArrayExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JNewArrayExpr$class_object;

#endif	/* _JC_soot_jimple_internal_JNewArrayExpr_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/internal/JNewArrayExpr.h <==
// public class soot.jimple.internal.JNewArrayExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class cc0d5acb5fd5a93a soot_jimple_internal_AbstractNewArrayExpr
// @dep_class 679d3e54c99aea5a soot_jimple_internal_JNewArrayExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractNewArrayExpr

#include "soot/jimple/internal/AbstractNewArrayExpr.h"

#ifndef _JC_soot_jimple_internal_JNewArrayExpr_H_
#define _JC_soot_jimple_internal_JNewArrayExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Type$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JNewArrayExpr$sub_refs	_jc_soot_jimple_internal_JNewArrayExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_JNewArrayExpr$sub_nonrefs	_jc_soot_jimple_internal_JNewArrayExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JNewArrayExpr$refs	_jc_soot_jimple_internal_JNewArrayExpr$refs;
typedef struct _jc_soot_jimple_internal_JNewArrayExpr$nonrefs	_jc_soot_jimple_internal_JNewArrayExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_JNewArrayExpr$object	_jc_soot_jimple_internal_JNewArrayExpr$object;

typedef const struct _jc_soot_jimple_internal_JNewArrayExpr$vmethods	_jc_soot_jimple_internal_JNewArrayExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_JNewArrayExpr$vtable	_jc_soot_jimple_internal_JNewArrayExpr$vtable;
typedef const struct _jc_soot_jimple_internal_JNewArrayExpr$vtype	_jc_soot_jimple_internal_JNewArrayExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JNewArrayExpr$method$_init$0b3348c37b519d7f(_jc_env *, struct _jc_soot_jimple_internal_JNewArrayExpr$object *, struct _jc_soot_Type$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JNewArrayExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JNewArrayExpr$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JNewArrayExpr$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_jimple_internal_JNewArrayExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JNewArrayExpr$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_internal_JNewArrayExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractNewArrayExpr$vmethods	soot_jimple_internal_AbstractNewArrayExpr;
	_jc_soot_jimple_internal_JNewArrayExpr$vmethods	soot_jimple_internal_JNewArrayExpr;
};

// Vtype
struct _jc_soot_jimple_internal_JNewArrayExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JNewArrayExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JNewArrayExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JNewArrayExpr$refs {
    _jc_soot_jimple_internal_JNewArrayExpr$sub_refs	soot_jimple_internal_JNewArrayExpr;
    _jc_soot_jimple_internal_AbstractNewArrayExpr$sub_refs	soot_jimple_internal_AbstractNewArrayExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JNewArrayExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JNewArrayExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractNewArrayExpr$sub_nonrefs	soot_jimple_internal_AbstractNewArrayExpr;
    _jc_soot_jimple_internal_JNewArrayExpr$sub_nonrefs	soot_jimple_internal_JNewArrayExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_JNewArrayExpr$object {
	_jc_soot_jimple_internal_JNewArrayExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JNewArrayExpr$vtype	*vtype;
	_jc_soot_jimple_internal_JNewArrayExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JNewArrayExpr$vtype _jc_soot_jimple_internal_JNewArrayExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JNewArrayExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JNewArrayExpr$class_object;

#endif	/* _JC_soot_jimple_internal_JNewArrayExpr_H_ */
